@@ -1,7 +1,7 @@
-from .classes import Colour, MinecraftIcons, Image, Filters
+from .classes import Colour, Filters, Image, MinecraftIcons
 from .client import BadRequest, Client, InternalServerError, NotFound
 from .errors import BadRequest, HTTPException, InternalServerError, NotFound
 
 __license__ = "MIT"
 __author__ = "Soheab_"
-__version__ = "2.1.0"
+__version__ = "2.1.1"
